ConditionOperator - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# ConditionOperator

class inmydata.StructuredData.ConditionOperator(value)

  Bases: `Enum`

  Enum representing an operator for filtering data in AIDataFilter.

  Equals

    Represents the equality condition.

  NotEquals

    Represents the inequality condition.

  GreaterThan

    Represents the greater than condition.

  LessThan

    Represents the less than condition.

  GreaterThanOrEqualTo

    Represents the greater than or equal to condition.

  LessThanOrEqualTo

    Represents the less than or equal to condition.

  StartsWith

    Represents the starts with condition.

  Like

    Represents the like condition.

  NotStartsWith

    Represents the not starts with condition.

  NotLike

    Represents the not like condition.

  Contains

    Represents the contains condition.

  NotContains

    Represents the not contains condition.

  Contains = 10
  Equals = 0
  GreaterThan = 2
  GreaterThanOrEqualTo = 4
  LessThan = 3
  LessThanOrEqualTo = 5
  Like = 7
  NotContains = 11
  NotEquals = 1
  NotLike = 9
  NotStartsWith = 8
  StartsWith = 6